package com.example.SparkStructedStreaming.Service;

import com.example.SparkStructedStreaming.Person;
import com.genericAvro.PersonData;
import io.confluent.kafka.serializers.KafkaAvroSerializer;
import org.apache.kafka.clients.producer.*;
import org.apache.kafka.common.protocol.types.Field;
import org.apache.kafka.common.serialization.StringSerializer;
import org.apache.spark.sql.ForeachWriter;
import org.apache.spark.sql.Row;

import java.util.Properties;

public class ForEachWriterImpl extends ForeachWriter<Person> {
    private Properties properties = new Properties();
    private Producer<String, PersonData> producer;
    private String topic;
    private PersonData personData;
    private ProducerRecord<String, PersonData> producerRecord;

    @Override
    public boolean open ( long l, long l1 ) {
        System.out.println("Inside open");
        properties.setProperty("bootstrap.servers", "http://127.0.0.1:9092");
        properties.setProperty("acks", "all");
        properties.setProperty("retries", "1");
        properties.setProperty("key.serializer", StringSerializer.class.getName());
        properties.setProperty("value.serializer", KafkaAvroSerializer.class.getName());
        properties.setProperty("schema.registry.url", "http://127.0.0.1:8081");
        return true;
    }

    @Override
    public void process ( Person person ) {
        try {
            producer = new KafkaProducer<String, PersonData>(properties);
            personData = mapPerson(person);
            System.out.println("Inside process");
            topic = personData.getName().trim().replace(" ","");
            producerRecord = new ProducerRecord<String, PersonData>(topic, personData);
            producer.send(producerRecord, new Callback() {
                @Override
                public void onCompletion ( RecordMetadata metadata, Exception exception ) {
                    if (exception == null) {
                        System.out.println("metadata : " + metadata);
                    } else {
                        exception.printStackTrace();
                    }
                }
            });

        } catch ( Exception e ) {
            e.printStackTrace();
        }

    }

    private PersonData mapPerson ( Person person ) {
        return PersonData.newBuilder()
                .setName(person.getName())
                .setAge(person.getAge()).build();
    }

    @Override
    public void close ( Throwable throwable ) {
        System.out.println("Inside close");
        System.out.println("Offer Processed ");
    }
}
