package com.example.SparkStructedStreaming.job;

import com.example.SparkStructedStreaming.config.SparkSessionConfig;
import org.apache.spark.sql.Dataset;
import org.apache.spark.sql.Row;
import org.apache.spark.sql.SparkSession;
import org.apache.spark.sql.streaming.OutputMode;
import org.apache.spark.sql.streaming.StreamingQueryException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class KafkaDataReaderJob {

   @Autowired
   SparkSession sparkSession;
    public void run(){

        Dataset<Row> rowDataSet = sparkSession
                .readStream()
                .format("kafka")
                .option("kafka.bootstrap.servers","http://127.0.0.1:9092")
                .option("subscribe","Person")
                .option("startingOffsets", "earliest")
                .option("failOnDataLoss","false")
                .load()
                .selectExpr("CAST(key AS STRING)", "CAST(value AS STRING)");
        rowDataSet.printSchema();

        try {
            rowDataSet.writeStream()
                    .format("console")
                    .option("checkpointLocation", "/tmp/SparkSession")
                    .outputMode(OutputMode.Append())
                    .start()
                    .awaitTermination();
        } catch ( StreamingQueryException e ) {
            e.printStackTrace();
        }
        finally {
            sparkSession.close();
        }

    }
}
